﻿# Specify the site code
$SiteCode = "S01"

# Specify the name of the task sequence template to be exported, and the name of the export file
$TSTemplateName = "Task Sequence Template"
$TSTemplateFile = "C:\Task Sequence Template\TStemplate.xml"

# Specify the names of the images and packages used in the task sequence
$WindowImageName = "Windows 8.1 Enterprise x64"
$SCCMClientPackageName = "SCCM Client With Hotfixes"
$USMTPackageName = "User State Migration Tool for Windows 8"
$MDTToolkitName = "MDT 2013 Toolkit Package"
$MDTSettingsPackageName = "MDT 2013 Settings Package For Windows 8.1 x64"

# Import the ConfigMgr module and set location
Import-Module (Join-Path $(Split-Path $env:SMS_ADMIN_UI_PATH) ConfigurationManager.psd1)
Set-Location ($SiteCode + ":")

# Export task sequence
(Get-CMTaskSequence | Where-Object {$_.Name -eq $TSTemplateName}).Sequence | Out-File $TSTemplateFile

# Get the Package IDs for the packages used in the task sequence
$TSReferenceWindowsImage = (Get-CMOperatingSystemImage | Where-Object {$_.Name -eq $WindowImageName}).PackageID
$TSReferenceClientPackage = (Get-CMPackage | Where-Object {$_.Name -eq $SCCMClientPackageName}).PackageID
$TSReferenceUSMT = (Get-CMPackage | Where-Object {$_.Name -eq $USMTPackageName}).PackageID
$TSReferenceMDTToolkit = (Get-CMPackage | Where-Object {$_.Name -eq $MDTToolkitName}).PackageID
$TSReferenceMDTSettings = (Get-CMPackage | Where-Object {$_.Name -eq $MDTSettingsPackageName}).PackageID

# Function to replace strings in a file
Function Replace-StringInFile([string]$FileName,[string]$TextToReplace,[string]$NewText)
{
    (Get-Content $FileName) | Foreach-Object {$_ -replace $TextToReplace, $NewText} | Set-Content $FileName -Encoding Unicode
}

# Replace all package ID's to some unique string that we can easily identify when importing the task sequence
Replace-StringInFile $TSTemplateFile $TSReferenceWindowsImage "UNIQUE_WINDOWS_IMAGE_ID"
Replace-StringInFile $TSTemplateFile $TSReferenceClientPackage "UNIQUE_CLIENT_PACKAGE_ID"
Replace-StringInFile $TSTemplateFile $TSReferenceUSMT "UNIQUE_USMT_PACKAGE_ID"
Replace-StringInFile $TSTemplateFile $TSReferenceMDTToolkit "UNIQUE_MDT_TOOLKIT_PACKAGE_ID"
Replace-StringInFile $TSTemplateFile $TSReferenceMDTSettings "UNIQUE_MDT_SETTINGS_PACKAGE_ID"


