﻿# Specify the site code
$SiteCode = "S01"

# Specify distribution point group
$DistributionPointGroup = "All DPs"

# Specify package names and source paths
$BootImageName = "MDT Boot Image x64"
$BootImagePath = "\\sccmrap\sources\OSD\Boot Images\WinPE 5.0\x64\winpe.wim"
$WindowsImageName = "Windows 8.1 Enterprise x64"
$WindowsImagePath = "\\sccmrap\sources\OSD\OS Images\Win8.1x64-20141015.wim"
$MDTToolkitPackageName = "MDT 2013 Toolkit Package"
$MDTToolkiTPackagePath = "\\sccmrap\sources\OSD\MDT 2013 Toolkit Package"
$MDTSettingsPackageName = "MDT 2013 Settings Package For Windows 8.1 x64"
$MDTSettingsPackagePath = "\\sccmrap\sources\OSD\MDT 2013 Settings Packages\Windows 8.1\x64"
$SCCMClientPackageName = "SCCM Client With Hotfixes"
$SCCMClientPackagePath = "\\sccmrap\Sources\Applications\SCCM Client With Hotfixes"

# Import the ConfigMgr module and set location
Import-Module (Join-Path $(Split-Path $env:SMS_ADMIN_UI_PATH) ConfigurationManager.psd1)
Set-Location ($SiteCode + ":")

# Import the boot image
New-CMBootImage -Name $BootImageName -Path $BootImagePath -Index 1

# Enable command support in the boot image
$BootImageWMIObject = Get-WmiObject -Namespace "Root\SMS\Site_$SiteCode" -Class SMS_BootImagePackage -Filter "Name='$BootImageName'"
$BootImageWMIObject.Get()
$BootImageWMIObject.EnableLabShell = 'True'
$BootImageWMIObject.Put()

# Deploy the boot image from PXE-enabled distribution points
$BootImageWMIObject.Get()
$BootImageWMIObject.PkgFlags = '1024'
$BootImageWMIObject.Put()

# Import the operating system image
New-CMOperatingSystemImage -Name $WindowsImageName -Path $WindowsImagePath

# Import the MDT toolkit package
New-CMPackage -Name $MDTToolkitPackageName -Path $MDTToolkitPackagePath

# Import the MDT settings package
New-CMPackage -Name $MDTSettingsPackageName -Path $MDTSettingsPackagePath

# Import the SCCM client package
New-CMPackage -Name $SCCMClientPackageName -Path $SCCMClientPackagePath

# Distribute the packages to the distribution point group
Start-CMContentDistribution -BootImageName $BootImageName -DistributionPointGroupName $DistributionPointGroup
Start-CMContentDistribution -OperatingSystemImageName $WindowsImageName -DistributionPointGroupName $DistributionPointGroup
Start-CMContentDistribution -PackageName $MDTToolkitPackageName -DistributionPointGroupName $DistributionPointGroup
Start-CMContentDistribution -PackageName $MDTSettingsPackageName -DistributionPointGroupName $DistributionPointGroup
Start-CMContentDistribution -PackageName $SCCMClientPackageName -DistributionPointGroupName $DistributionPointGroup

