﻿# Specify the site code
$SiteCode = "S01"

# Specify the name of the task sequence template file that will be imported
$TSTemplateFile = "C:\Task Sequence Template\TStemplate.xml"

# Specify the name of the new task sequence that will be created
$TSName = "Install Windows 8.1 x64"

# Specify the names of the images and packages used in the task sequence
$BootImageName = "MDT Boot Image x64"
$WindowImageName = "Windows 8.1 Enterprise x64"
$SCCMClientPackageName = "SCCM Client With Hotfixes"
$USMTPackageName = "User State Migration Tool for Windows 8"
$MDTToolkitName = "MDT 2013 Toolkit Package"
$MDTSettingsPackageName = "MDT 2013 Settings Package For Windows 8.1 x64"

# Name of the unique strings in the task sequence template file that represent the package ID's 
$TSReferenceWindowsImage = "UNIQUE_WINDOWS_IMAGE_ID"
$TSReferenceClientPackage = "UNIQUE_CLIENT_PACKAGE_ID"
$TSReferenceUSMT = "UNIQUE_USMT_PACKAGE_ID"
$TSReferenceMDTToolkit = "UNIQUE_MDT_TOOLKIT_PACKAGE_ID"
$TSReferenceMDTSettings = "UNIQUE_MDT_SETTINGS_PACKAGE_ID"

# Import the ConfigMgr module and set location
Import-Module (Join-Path $(Split-Path $env:SMS_ADMIN_UI_PATH) ConfigurationManager.psd1)
Set-Location ($SiteCode + ":")

# Get the Package IDs for the packages used in the task sequence
$TSReferenceBootImage = (Get-CMBootImage | Where-Object {$_.Name -eq $BootImageName}).PackageID
$TSReferenceWindowsImageNEW = (Get-CMOperatingSystemImage | Where-Object {$_.Name -eq $WindowImageName}).PackageID
$TSReferenceClientPackageNEW = (Get-CMPackage | Where-Object {$_.Name -eq $SCCMClientPackageName}).PackageID
$TSReferenceUSMTNEW = (Get-CMPackage | Where-Object {$_.Name -eq $USMTPackageName}).PackageID
$TSReferenceMDTToolkitNEW = (Get-CMPackage | Where-Object {$_.Name -eq $MDTToolkitName}).PackageID
$TSReferenceMDTSettingsNEW = (Get-CMPackage | Where-Object {$_.Name -eq $MDTSettingsPackageName}).PackageID

# Function to replace strings in a file
Function Replace-StringInFile([string]$FileName,[string]$TextToReplace,[string]$NewText)
{
    (Get-Content $FileName) | Foreach-Object {$_ -replace $TextToReplace, $NewText} | Set-Content $FileName -Encoding Unicode
}

# Copy the task sequence template file to a new file that we will use for import, so that we don't destroy the original
$TSTemplateImportFile = $TSTemplateFile.Substring(0,$TSTemplateFile.Length-4) + "-IMPORTFILE.xml"
Copy-Item $TSTemplateFile $TSTemplateImportFile -Force

# Replace all package ID's in the task sequence template file with the actual ID's of the packages that will be used
Replace-StringInFile $TSTemplateImportFile $TSReferenceWindowsImage $TSReferenceWindowsImageNEW
Replace-StringInFile $TSTemplateImportFile $TSReferenceClientPackage $TSReferenceClientPackageNEW
Replace-StringInFile $TSTemplateImportFile $TSReferenceUSMT $TSReferenceUSMTNEW
Replace-StringInFile $TSTemplateImportFile $TSReferenceMDTToolkit $TSReferenceMDTToolkitNEW
Replace-StringInFile $TSTemplateImportFile $TSReferenceMDTSettings $TSReferenceMDTSettingsNEW

# Import the task sequence
$WMIClass = "SMS_TaskSequencePackage"
$TS = [wmiclass]"\\.\root\sms\site_$($SiteCode):$($WMIClass)"
$Instance = $TS.CreateInstance()
$TSFileContent = Get-Content $TSTemplateImportFile
$NewSequence = $TS.ImportSequence($TSFileContent).TaskSequence
$Instance.Name = $TSName
$NewTSPackageID = $TS.SetSequence($Instance, $NewSequence).SavedTaskSequencePackagePath

# Assign a boot image to the task sequence
$ImportedTaskSequence = Get-CMTaskSequence -Name $TSName
Set-CMTaskSequence -TaskSequence $ImportedTaskSequence -BootImageId $TSReferenceBootImage -UseBootImage $True -UseDefaultText $True